@@ -307,7 +307,8 @@ class Conform(SimpleInterface):
             out_name = fname
 
         transform = ornt_xfm.dot(conform_xfm)
-        assert np.allclose(orig_img.affine.dot(transform), target_affine)
+        if not np.allclose(orig_img.affine.dot(transform), target_affine):
+            raise ValueError("Original and target affines are not similar")
 
         mat_name = fname_presuffix(fname, suffix='.mat', newpath=runtime.cwd, use_ext=False)
         np.savetxt(mat_name, transform, fmt='%.08f')
@@ -332,7 +333,7 @@ class ValidateImage(SimpleInterface):
     Check the correctness of x-form headers (matrix and code).
 
     This interface implements the `following logic
-    <https://github.com/poldracklab/fmriprep/issues/873#issuecomment-349394544>`_:
+    <https://github.com/nipreps/fmriprep/issues/873#issuecomment-349394544>`_:
 
     +-------------------+------------------+------------------+------------------\
 +------------------------------------------------+
@@ -420,25 +421,28 @@ class ValidateImage(SimpleInterface):
         elif (valid_sform and sform_code > 0) and (not matching_affines or qform_code == 0):
             img.set_qform(sform, sform_code)
             new_qform = img.get_qform()
-            if np.allclose(new_qform, qform) and qform_code > 0:
-                # False alarm
-                self._results['out_file'] = self.inputs.in_file
-                open(out_report, 'w').close()
-                self._results['out_report'] = out_report
-                return runtime
-            diff = np.linalg.inv(qform) @ new_qform
-            trans, rot, _, _ = transforms3d.affines.decompose44(diff)
-            angle = transforms3d.axangles.mat2axangle(rot)[1]
-            total_trans = np.sqrt(np.sum(trans * trans))  # Add angle and total_trans to report
-            warning_txt = 'Note on orientation: qform matrix overwritten'
-            description = """\
+            if valid_qform:
+                # False alarm - the difference is due to precision loss of qform
+                if np.allclose(new_qform, qform) and qform_code > 0:
+                    self._results['out_file'] = self.inputs.in_file
+                    open(out_report, 'w').close()
+                    self._results['out_report'] = out_report
+                    return runtime
+                # Replacing an existing, valid qform. Report magnitude of change.
+                diff = np.linalg.inv(qform) @ new_qform
+                trans, rot, _, _ = transforms3d.affines.decompose44(diff)
+                angle = transforms3d.axangles.mat2axangle(rot)[1]
+                total_trans = np.sqrt(np.sum(trans * trans))  # Add angle and total_trans to report
+                warning_txt = 'Note on orientation: qform matrix overwritten'
+                description = """\
     <p class="elem-desc">
     The qform has been copied from sform.
     The difference in angle is {angle:.02g}.
     The difference in translation is {total_trans:.02g}.
     </p>
     """.format(angle=angle, total_trans=total_trans)
-            if not valid_qform and qform_code > 0:
+            elif qform_code > 0:
+                # qform code indicates the qform is supposed to be valid. Use more stridency.
                 warning_txt = 'WARNING - Invalid qform information'
                 description = """\
 <p class="elem-desc">
@@ -448,6 +452,10 @@ class ValidateImage(SimpleInterface):
     by the scanner is advised.
 </p>
 """
+            else:  # qform_code == 0
+                # qform is not expected to be valids. Simple note.
+                warning_txt = 'Note on orientation: qform matrix overwritten'
+                description = '<p class="elem-desc">The qform has been copied from sform.</p>'
         # Rows 5-6:
         else:
             affine = img.header.get_base_affine()
@@ -577,22 +585,6 @@ def reorient(in_file, newpath=None):
     return out_file
 
 
-def extract_wm(in_seg, wm_label=3, newpath=None):
-    import nibabel as nb
-    import numpy as np
-    from nipype.utils.filemanip import fname_presuffix
-
-    nii = nb.load(in_seg)
-    data = np.zeros(nii.shape, dtype=np.uint8)
-    data[np.asanyarray(nii.dataobj) == wm_label] = 1
-
-    out_file = fname_presuffix(in_seg, suffix='_wm', newpath=newpath)
-    new = nb.Nifti1Image(data, nii.affine, nii.header)
-    new.set_data_dtype(np.uint8)
-    new.to_filename(out_file)
-    return out_file
-
-
 def normalize_xform(img):
     """
     Set identical, valid qform and sform matrices in an image.
@@ -731,7 +723,7 @@ class SignalExtraction(SimpleInterface):
             raise NotImplementedError(
                 "Input image and mask should be of "
                 "same dimensions before running SignalExtraction"
-                )
+            )
         # Load the mask.
         # If mask is a list, each mask is treated as its own ROI/parcel
         # If mask is a 3D, each integer is treated as its own ROI/parcel
@@ -742,7 +734,7 @@ class SignalExtraction(SimpleInterface):
             labelsmap = np.asanyarray(mask_imgs[0].dataobj)
             labels = np.unique(labelsmap)
             labels = labels[labels != 0]
-            masks = [labelsmap == l for l in labels]
+            masks = [labelsmap == label for label in labels]
 
         if len(masks) != len(self.inputs.class_labels):
             raise ValueError("Number of masks must match number of labels")
