@@ -172,9 +172,10 @@ class ACompCorRPT(nrc.SegmentationRC, confounds.ACompCor):
     def _post_run_hook(self, runtime):
         ''' generates a report showing slices from each axis '''
 
-        assert len(self.inputs.mask_files) == 1, \
-            "ACompCorRPT only supports a single input mask. " \
-            "A list %s was found." % self.inputs.mask_files
+        if len(self.inputs.mask_files) != 1:
+            raise ValueError(
+                "ACompCorRPT only supports a single input mask. "
+                "A list %s was found." % self.inputs.mask_files)
         self._anat_file = self.inputs.realigned_file
         self._mask_file = self.inputs.mask_files[0]
         self._seg_files = self.inputs.mask_files
@@ -205,9 +206,11 @@ class TCompCorRPT(nrc.SegmentationRC, confounds.TCompCor):
 
         high_variance_masks = self.aggregate_outputs(runtime=runtime).high_variance_masks
 
-        assert not isinstance(high_variance_masks, list),\
-            "TCompCorRPT only supports a single output high variance mask. " \
-            "A list %s was found." % str(high_variance_masks)
+        if isinstance(high_variance_masks, list):
+            raise ValueError(
+                "TCompCorRPT only supports a single output high variance mask. "
+                "A list %s was found." % high_variance_masks
+            )
         self._anat_file = self.inputs.realigned_file
         self._mask_file = high_variance_masks
         self._seg_files = [high_variance_masks]
@@ -260,7 +263,7 @@ class ROIsPlot(nrc.ReportingInterface):
             else self.inputs.in_mask
 
         # Remove trait decoration and replace None with []
-        levels = [l for l in self.inputs.levels or []]
+        levels = [level for level in self.inputs.levels or []]
         colors = [c for c in self.inputs.colors or []]
 
         if len(seg_files) == 1:  # in_rois is a segmentation
