@@ -1,12 +1,12 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""
-Miscellaneous utilities
-"""
+"""Miscellaneous utilities."""
+import os
+import shutil
 
 
 __all__ = ['get_template_specs', 'fix_multi_T1w_source_name', 'add_suffix', 'read_crashfile',
-           'splitext', '_copy_any']
+           'splitext', '_copy_any', 'clean_directory']
 
 
 def get_template_specs(in_template, template_spec=None, default_resolution=1):
@@ -166,8 +166,11 @@ def _read_txt(path):
 
 
 def splitext(fname):
-    """Splits filename and extension (.gz safe)
+    """
+    Split filename in name and extension (.gz safe).
 
+    Examples
+    --------
     >>> splitext('some/file.nii.gz')
     ('file', '.nii.gz')
     >>> splitext('some/other/file.nii')
@@ -176,6 +179,12 @@ def splitext(fname):
     ('otherext', '.tar.gz')
     >>> splitext('text.txt')
     ('text', '.txt')
+    >>> splitext('some/figure.svg')
+    ('figure', '.svg')
+    >>> splitext('some/figure.svg.gz')
+    ('figure', '.svg.gz')
+    >>> splitext('some/sub-01_bold.func.gii')
+    ('sub-01_bold.func', '.gii')
 
     """
     from pathlib import Path
@@ -204,7 +213,7 @@ def _copy_any(src, dst):
     with src_open(src, 'rb') as f_in:
         with open(dst, 'wb') as f_out:
             if dst_isgz:
-                # Remove FNAME header from gzip (poldracklab/fmriprep#1480)
+                # Remove FNAME header from gzip (nipreps/fmriprep#1480)
                 gz_out = gzip.GzipFile('', 'wb', 9, f_out, 0.)
                 copyfileobj(f_in, gz_out)
                 gz_out.close()
@@ -214,5 +223,94 @@ def _copy_any(src, dst):
     return True
 
 
+def clean_directory(path):
+    """
+    Clears a directory of all contents.
+
+    Returns `True` if no content remains. If any content cannot be removed, returns `False`.
+
+    Notes
+    -----
+    This function is not guaranteed to work across multiple threads or processes.
+
+    """
+    for f in os.scandir(path):  # switch to context manager when py35 dropped
+        if f.is_file() or f.is_symlink():
+            try:
+                os.unlink(f.path)
+            except OSError:
+                return False
+        elif f.is_dir():
+            try:
+                shutil.rmtree(f.path)
+            except OSError:
+                return False
+    return True
+
+
+def pass_dummy_scans(algo_dummy_scans, dummy_scans=None):
+    """
+    Graft manually provided number of dummy scans, if necessary.
+
+    Parameters
+    ----------
+    algo_dummy_scans : int
+        number of volumes to skip determined by an algorithm
+    dummy_scans : int or None
+        number of volumes to skip determined by the user
+
+    Returns
+    -------
+    skip_vols_num : int
+        number of volumes to skip
+
+    """
+    if dummy_scans is None:
+        return algo_dummy_scans
+    return dummy_scans
+
+
+def check_valid_fs_license(lic=None):
+    """
+    Run ``mri_convert`` to assess FreeSurfer access to a license.
+
+    Parameters
+    ----------
+    lic : :obj:`str`, optional
+        Path to FreeSurfer license file
+
+    Returns
+    -------
+    valid : :obj:`bool`
+        FreeSurfer license is valid
+
+    """
+    from pathlib import Path
+    import subprocess as sp
+    from tempfile import TemporaryDirectory
+
+    import nibabel as nb
+    import numpy as np
+
+    if lic is not None:
+        import os
+        os.environ['FS_LICENSE'] = str(Path(lic).absolute())
+
+    with TemporaryDirectory() as tmpdir:
+        nii_file = str(Path(tmpdir) / 'test.nii.gz')
+        out_file = str(Path(tmpdir) / 'out.mgz')
+        # create test NIfTI
+        nb.Nifti1Image(np.zeros((5, 5, 5)), np.eye(4)).to_filename(nii_file)
+        # quick FreeSurfer command
+        _cmd = (
+            'mri_convert',
+            '--out_type', 'mgz',
+            '--input_volume', nii_file,
+            '--output_volume', out_file
+        )
+        proc = sp.run(_cmd, stdout=sp.PIPE, stderr=sp.PIPE)
+    return "ERROR: FreeSurfer license file" not in proc.stderr.decode()
+
+
 if __name__ == '__main__':
     pass
