@@ -219,6 +219,19 @@ class Reference:
                 'space identifier "%s" is invalid.\nValid '
                 'identifiers are: %s' % (value, ', '.join(valid)))
 
+    def __str__(self):
+        """
+        Format this reference.
+
+        Examples
+        --------
+        >>> str(Reference(space='MNIPediatricAsym', spec={'cohort': 2, 'res': 1}))
+        'MNIPediatricAsym:cohort-2:res-1'
+
+        """
+        return ':'.join([self.space] + [
+            '-'.join((k, str(v))) for k, v in sorted(self.spec.items())])
+
     @classmethod
     def from_string(cls, value):
         """
@@ -473,18 +486,14 @@ class SpatialReferences:
         Spatial References: <none>.
 
         >>> print(SpatialReferences(['MNI152NLin2009cAsym']))
-        Spatial References:
-            - Reference(space='MNI152NLin2009cAsym', spec={})
+        Spatial References: MNI152NLin2009cAsym
 
         >>> print(SpatialReferences(['MNI152NLin2009cAsym', 'fsaverage5']))
-        Spatial References:
-            - Reference(space='MNI152NLin2009cAsym', spec={})
-            - Reference(space='fsaverage', spec={'den': '10k'})
+        Spatial References: MNI152NLin2009cAsym, fsaverage:den-10k
 
         """
-        spaces = '\n    - '.join([''] + [str(s) for s in self.references]) \
-            if self.references else ' <none>.'
-        return 'Spatial References:%s' % spaces
+        spaces = ', '.join([str(s) for s in self.references]) or '<none>.'
+        return 'Spatial References: %s' % spaces
 
     @property
     def references(self):
@@ -651,10 +660,17 @@ class OutputReferencesAction(argparse.Action):
             spaces.checkpoint()
         for val in values:
             val = val.rstrip(":")
-            # Should we support some sort of explicit "default" resolution?
-            # https://github.com/nipreps/niworkflows/pull/457#discussion_r375510227
-            # if ":res-" not in val or ":resolution-" not in val:
-            #     val = ":".join((val, "res-default"))
+            if (
+                val not in NONSTANDARD_REFERENCES
+                and not val.split(':')[0].startswith('fs')
+                and ":res-" not in val
+                and ":resolution-" not in val
+            ):
+                # by default, explicitly set volumetric resolution to native
+                # relevant discussions:
+                # https://github.com/nipreps/niworkflows/pull/457#discussion_r375510227
+                # https://github.com/nipreps/niworkflows/pull/494
+                val = ":".join((val, "res-native"))
             for sp in Reference.from_string(val):
                 spaces.add(sp)
         setattr(namespace, self.dest, spaces)
@@ -687,6 +703,34 @@ def format_reference(in_tuple):
     return '_'.join(out)
 
 
+def reference2dict(in_tuple):
+    """
+    Split a spatial reference given as a tuple into a dictionary.
+
+    Examples
+    --------
+    >>> reference2dict(('MNIPediatricAsym:cohort-2', {'res': 2}))
+    {'space': 'MNIPediatricAsym', 'cohort': '2', 'resolution': '2'}
+
+    >>> reference2dict(('MNIPediatricAsym:cohort-2', {'res': 2, 'resolution': 1}))
+    {'space': 'MNIPediatricAsym', 'cohort': '2', 'resolution': '1'}
+
+    >>> reference2dict(('MNIPediatricAsym:cohort-2', {'res': 2, 'den': '91k'}))
+    {'space': 'MNIPediatricAsym', 'cohort': '2', 'resolution': '2', 'density': '91k'}
+
+    """
+    tpl_entities = ("space", "cohort")
+    retval = {
+        tpl_entities[i]: v.split("-")[i]
+        for i, v in enumerate(in_tuple[0].split(':'))
+    }
+    retval.update({
+        "resolution" if k == "res" else "density" if k == "den" else k: f"{v}"
+        for k, v in in_tuple[1].items()
+    })
+    return retval
+
+
 def _expand_entities(entities):
     """
     Generate multiple replacement queries based on all combinations of values.
